#######################################################################
# Copyright (c) 2025 ENEO Tecnologia S.L.
# This file is part of redBorder.
# redBorder is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# redBorder is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# You should have received a copy of the GNU Affero General Public License
# along with redBorder. If not, see <http://www.gnu.org/licenses/>.
#######################################################################

class InventoryDeviceTypeObject < ApplicationRecord
  belongs_to :criticality
  
  validates_uniqueness_of :name

  before_destroy :prevent_destroy_if_locked
  before_update :prevent_name_change_if_locked

  before_destroy :remove_inventory_devices_association

  has_many :inventory_devices

  def prevent_destroy_if_locked
    if locked
      errors.add(:base, "Cant delete locked objects.")
      throw(:abort)
    end
  end

  def prevent_name_change_if_locked
    if locked && name_changed?
      errors.add(:name, "Cant change name of locked objects.")
      throw(:abort)
    end
  end

  def remove_inventory_devices_association
    inventory_devices.update_all(inventory_device_type_object_id: nil) if inventory_devices.exists?
  end
end
